/*
 * Copyright (c) 2009, Mason Green (zzzzrrr)
 * http://www.dsource.org/projects/openmelee
 * 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * * Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 * * Neither the name of the polygonal nor the names of its contributors may be
 *   used to endorse or promote products derived from this software without specific
 *   prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
module openmelee.ai.human;

import xf.hybrid.Event;
import xf.input.KeySym;

import openmelee.ships.ship;
import openmelee.melee.melee : Melee;

class Human
{
    Melee melee;
    Ship ship;
    
	this(Ship ship, Melee melee) {
        this.melee = melee;
        this.ship = ship;
	}

	EventHandling onClick(MouseButtonEvent e) {
        return EventHandling.Stop;
	}

	EventHandling onKey(KeyboardEvent e) {
        // Key pressed
		if (e.down) {
			switch (e.keySym) {
            case KeySym.space:
                drawAABBs = !drawAABBs;
                break;
			case KeySym.Escape:
                quit = true;
                break;
            case KeySym.Up:            
                thrust = true;
                break;
            case KeySym.Left:            
                ship.turnLeft();
                break;
            case KeySym.Right:             
                ship.turnRight();
                break;
            case KeySym.Down:             
                break;
            case KeySym.Delete:
                melee.ship2.explode();
                melee.objectList.remove(melee.ship2);
                melee.world.destroyBody(melee.ship2.rBody);
                melee.ship2 = null;
                melee.draw.ship2 = null;
                melee.ai.ship = null;
			default:
				break;
			}
        // Key released
		} else {
		    if(e.keySym == KeySym.Up) {
		         thrust = false;
		    } else if (e.keySym == KeySym.Left || e.keySym == KeySym.Right) {
                ship.rBody.angularVelocity = 0.0f;
            }
		}
		return EventHandling.Stop;
	}

	// Mouse move
	EventHandling onMove(MouseMoveEvent e) {
		return EventHandling.Stop;
	}

	EventHandling onDT(TimeUpdateEvent e){
		return EventHandling.Continue;
	}

	EventHandling onMouseEnter(MouseEnterEvent e) {
		return EventHandling.Continue;
	}

	EventHandling onMouseLeave(MouseLeaveEvent e) {
		return EventHandling.Continue;
	}

	bool quit;
    bool thrust;
    bool drawAABBs;
}
